/**
* @context admin,main
*/
AJS.toInit(function () {
	AJS.$.favoritesMenu.init();
});


AJS.$.favoritesMenu = {
	init: function () {
		var t = this;
	
		//Add favorites menu and populate on page load
		var favs = t.getFavoritePages();
		if (favs.length > 0 ) {
			t.addFavoritesMenu();
			t.populateFavoritesMenu(favs);
			t.orderFavoritesMenu();
		}

		//Add click handler to favorite button to add/remove menu item without need for page refresh
		AJS.$('#page-favourite').click(function() {
			//Currently a favorite remove from menu
			if(AJS.$('#page-favourite').text().indexOf('Remove') != -1) {
				//Remove the item
				t.removeFavoriteItem(document.URL);
				
				//Did we remove the last item if so kill the menu
				if(AJS.$('#favorite-pages-menu .aui-dropdown2-section ul li').length == 0) {
					t.removeFavoritesMenu();
				}
			}
			//Not currently a favorite
			else {
				//We don't have a favorites menu ... create it
				if(AJS.$('#favorite-pages-link').length == 0) {
					t.addFavoritesMenu();
				}
				
				//Add item ... order list
				t.addFavoriteItem(document.URL, AJS.$('#title-text a').text());
				t.orderFavoritesMenu();
			}
		});
	},
	
	addFavoritesMenu: function() {
		var menu = '<li id="favorite-pages-list_item"><a class="aui-nav-link aui-dropdown2-trigger" id="favorite-pages-link" title="Favorite Pages" aria-owns="favorite-pages-menu" aria-haspopup="true" aria-controls="favorite-pages-menu"><span>Favorites</span></a><div class="aui-dropdown2 aui-style-default aui-dropdown2-in-header" id="favorite-pages-menu" aria-hidden="true" data-dropdown2-alignment="left"><div class="aui-dropdown2-section"><ul></ul></div></div></li>';

		AJS.$('#header .aui-header-inner .aui-header-secondary .aui-nav').prepend(menu);
	},

	populateFavoritesMenu: function(data) {
		var items = "";

		for(var dat in data) {
			items += '<li><a href="' + data[dat].url + '">' + data[dat].title + '</a></li>';
		}

		AJS.$('#favorite-pages-menu .aui-dropdown2-section ul').html(items);
	},
	
	addFavoriteItem: function(url, text) {
		var item = '<li><a href="' + url + '">' + text + '</a></li>';
		
		AJS.$('#favorite-pages-menu .aui-dropdown2-section ul').append(item);
	},

	getFavoritePages: function() {
		var favs = [];

		//Get base confluence directory
		var base = AJS.$('#confluence-base-url').attr('content');
		var baseArray = base.split( '/' );
		var url = baseArray[0] + '//' + baseArray[2];
		base = base.replace(url, '');
		if(base.length != 0 && base.charAt(base.length - 1) === "/") {
			base = base.slice(0, -1);
		}
		
		AJS.$.ajax({
			dataType: 'json',
			contentType: 'application/json',
			type: 'POST',
			url: base + '/rpc/json-rpc/confluenceservice-v2/getLabelContentByName',
			data: '["my:favourite"]',
			async: false,
			success: function(data){
				var innerFavs = [];

				for(var dat in data) {
					if(data[dat].type === 'page') {
						innerFavs.push(data[dat]);
					}
				}

				favs = innerFavs;
			}
		});

		return favs;
	},

	removeFavoritesMenu: function() {
		AJS.$('#favorite-pages-list_item').remove();
	},

	removeFavoriteItem: function(url) {
		var items = $('#favorite-pages-menu .aui-dropdown2-section ul li');
		
		AJS.$.each(items, function(idx, item) {
			if(AJS.$('a', item).attr('href').toUpperCase() === url.toUpperCase()) {
				AJS.$(item).remove();
			}
		});
	},

	orderFavoritesMenu: function() {
		var mylist = AJS.$('#favorite-pages-menu .aui-dropdown2-section ul');
		
		var listitems = mylist.children('li').get();
		
		listitems.sort(function(a, b) {
		   return AJS.$(a).text().toUpperCase().localeCompare(AJS.$(b).text().toUpperCase());
		})
		
		AJS.$.each(listitems, function(idx, itm) { mylist.append(itm); });
	}
};